@@ -283,24 +283,26 @@ class Reactor(IReactor):
         from orionis.console.commands.__publisher__ import PublisherCommand
         from orionis.console.commands.cache_clear import CacheClearCommand
         from orionis.console.commands.help import HelpCommand
-        from orionis.console.commands.log_clear import LogClearCommand
         from orionis.console.commands.make_command import MakeCommand
         from orionis.console.commands.scheduler_list import ScheduleListCommand
         from orionis.console.commands.scheduler_work import ScheduleWorkCommand
         from orionis.console.commands.test import TestCommand
         from orionis.console.commands.version import VersionCommand
+        from orionis.console.commands.make_scheduler_listener import MakeSchedulerListenerCommand
+        from orionis.console.commands.server import ServerCommand
 
         # List of core command classes to load (extend this list as more core commands are added)
         core_commands = [
             PublisherCommand,
             CacheClearCommand,
             HelpCommand,
-            LogClearCommand,
             MakeCommand,
             ScheduleListCommand,
             ScheduleWorkCommand,
             TestCommand,
-            VersionCommand
+            VersionCommand,
+            MakeSchedulerListenerCommand,
+            ServerCommand
         ]
 
         # Iterate through the core command classes and register them
