@@ -1,7 +1,7 @@
 import asyncio
 from datetime import datetime
 import logging
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 from apscheduler.events import (
     EVENT_JOB_ERROR,
     EVENT_JOB_EXECUTED,
@@ -15,6 +15,9 @@ from apscheduler.events import (
     EVENT_SCHEDULER_STARTED,
 )
 from apscheduler.schedulers.asyncio import AsyncIOScheduler as APSAsyncIOScheduler
+from apscheduler.schedulers.base import BaseScheduler
+from apscheduler.schedulers.base import STATE_PAUSED, STATE_RUNNING
+from apscheduler.triggers.date import DateTrigger
 from rich.console import Console
 from rich.panel import Panel
 from rich.text import Text
@@ -77,7 +80,7 @@ class Schedule(ISchedule):
         """
 
         # List of operations that can be performed on the scheduler
-        self.__operations = [
+        self.__control_operations = [
             'schedule:pause',
             'schedule:resume',
             'schedule:shutdown'
@@ -94,6 +97,7 @@ class Schedule(ISchedule):
 
         # Initialize the AsyncIOScheduler with the configured timezone.
         self.__scheduler = APSAsyncIOScheduler(timezone=self.__tz)
+        self.__control_scheduler = APSAsyncIOScheduler(timezone=self.__tz)
 
         # Disable APScheduler's internal logging to avoid duplicate/conflicting logs.
         self.__disableLogging()
@@ -116,15 +120,15 @@ class Schedule(ISchedule):
         # Initialize the dictionary to manage event listeners.
         self.__listeners: Dict[str, callable] = {}
 
-        # Initialize a set to track jobs paused by pauseEverythingAt.
-        self.__pausedByPauseEverything: set = set()
-
         # Initialize the asyncio event used to signal scheduler shutdown.
         self._stopEvent: Optional[asyncio.Event] = None
 
         # Retrieve and initialize the catch instance for exception handling.
         self.__catch: ICatch = app.make(ICatch)
 
+        # Initialize the paused at timestamp
+        self.__paused_at: Optional[datetime] = None
+
     def __disableLogging(
         self
     ) -> None:
@@ -211,11 +215,6 @@ class Schedule(ISchedule):
         # Get the current time in the scheduler's configured timezone
         now = datetime.now(self.__tz)
 
-        # Log the timezone currently assigned to the scheduler for traceability
-        self.__logger.info(
-            f"Timezone assigned to the scheduler: {self.__app.config('app.timezone') or 'UTC'}"
-        )
-
         # Return the formatted current time string
         return now.strftime("%Y-%m-%d %H:%M:%S")
 
@@ -489,7 +488,7 @@ class Schedule(ISchedule):
         _misfire_grace_time = self.__getAttribute(data, 'misfire_grace_time', None)
 
         # Extract the job max_instances if available
-        _max_instances = self.__getAttribute(data, 'max_instances', 0)
+        _max_instances = self.__getAttribute(data, 'max_instances', 1)
 
         # Extract the job coalesce if available
         _coalesce = self.__getAttribute(data, 'coalesce', False)
@@ -739,6 +738,27 @@ class Schedule(ISchedule):
                     )
                 )
 
+    def __getPID(
+        self
+    ) -> int:
+        """
+        Retrieve the current process ID (PID) of the running scheduler.
+
+        This method obtains the process ID of the current Python process using the `os` module.
+        The PID is a unique identifier assigned by the operating system to each running process.
+        This information can be useful for logging, monitoring, or managing the scheduler process.
+
+        Returns
+        -------
+        int
+            The process ID (PID) of the current Python process.
+        """
+
+        import os
+
+        # Return the current process ID using os.getpid()
+        return os.getpid()
+
     def __startedListener(
         self,
         event
@@ -771,13 +791,12 @@ class Schedule(ISchedule):
         # Add a blank line for better formatting
         self.__rich_console.line()
         panel_content = Text.assemble(
-            (" Orionis Scheduler Worker ", "bold white on green"),                      # Header text with styling
-            ("\n\n", ""),                                                               # Add spacing
-            ("The scheduled tasks worker has started successfully.\n", "white"),        # Main message
-            (f"Started at: {now}\n", "dim"),                                            # Display the start time in dim text
-            ("To stop the worker, press ", "white"),                                    # Instruction text
-            ("Ctrl+C", "bold yellow"),                                                  # Highlight the key combination
-            (".", "white")                                                              # End the instruction
+            ("🚀 Orionis Scheduler Worker ", "bold white on green"),
+            ("\n\n", ""),
+            ("✅ The scheduled tasks worker has started successfully.\n", "white"),
+            (f"🕒 Started at: {now} | 🌐 Timezone: {self.__tz.key} | 🆔 PID: {self.__getPID()}\n", "dim"),
+            ("🛑 To stop the worker, press ", "white"),
+            ("Ctrl+C", "bold yellow")
         )
 
         # Display the message in a styled panel
@@ -800,6 +819,11 @@ class Schedule(ISchedule):
         # Log an informational message indicating that the scheduler has started
         self.__logger.info(f"Orionis Scheduler started successfully at: {now}.")
 
+        # Log the timezone currently assigned to the scheduler for traceability
+        self.__logger.info(
+            f"Timezone assigned to the scheduler: {self.__tz.key}."
+        )
+
     def __shutdownListener(
         self,
         event
@@ -878,9 +902,6 @@ class Schedule(ISchedule):
         event_exception = self.__getAttribute(event, 'exception', None)
         event_traceback = self.__getAttribute(event, 'traceback', None)
 
-        # Log an error message indicating that the job raised an exception
-        self.__logger.error(f"Task '{event_id}' raised an exception: {event_exception}")
-
         # Retrieve the job event data and update it with error details
         job_event_data = self.__getTaskFromSchedulerById(event_id)
         job_event_data.code = event_code
@@ -939,9 +960,6 @@ class Schedule(ISchedule):
         event_id = self.__getAttribute(event, 'job_id', None)
         event_code = self.__getAttribute(event, 'code', 0)
 
-        # Log an informational message indicating that the job has been submitted to the executor
-        self.__logger.info(f"Task '{event_id}' submitted to executor.")
-
         # Create an event entity for the submitted job, including its ID and code
         data_event = self.__getTaskFromSchedulerById(event_id, event_code)
 
@@ -983,9 +1001,6 @@ class Schedule(ISchedule):
         event_id = self.__getAttribute(event, 'job_id', None)
         event_code = self.__getAttribute(event, 'code', 0)
 
-        # Log an informational message indicating that the job has been executed
-        self.__logger.info(f"Task '{event_id}' executed.")
-
         # Create an event entity for the executed job, including its ID and code
         data_event = self.__getTaskFromSchedulerById(event_id, event_code)
 
@@ -1025,15 +1040,9 @@ class Schedule(ISchedule):
 
         # Extract the job ID from the event object, or None if not present
         event_id = self.__getAttribute(event, 'job_id', None)
+
         # Extract the event code from the event object, defaulting to 0 if not present
         event_code = self.__getAttribute(event, 'code', 0)
-        # Extract the scheduled run time from the event object, or 'Unknown' if not present
-        event_scheduled_run_time = self.__getAttribute(event, 'scheduled_run_time', 'Unknown')
-
-        # Log a warning indicating that the job was missed and when it was scheduled to run
-        self.__logger.warning(
-            f"Task '{event_id}' was missed. It was scheduled to run at: {event_scheduled_run_time}."
-        )
 
         # Create an event entity for the missed job, including its ID and code
         data_event = self.__getTaskFromSchedulerById(event_id, event_code)
@@ -1077,9 +1086,6 @@ class Schedule(ISchedule):
         event_id = self.__getAttribute(event, 'job_id', None)
         event_code = self.__getAttribute(event, 'code', 0)
 
-        # Log an error message indicating that the job exceeded maximum concurrent instances
-        self.__logger.error(f"Task '{event_id}' exceeded maximum instances")
-
         # Create an event entity for the job that exceeded max instances
         data_event = self.__getTaskFromSchedulerById(event_id, event_code)
 
@@ -1120,27 +1126,109 @@ class Schedule(ISchedule):
         event_id = self.__getAttribute(event, 'job_id', None)
         event_code = self.__getAttribute(event, 'code', 0)
 
-        # Log the removal of the job
-        self.__logger.info(f"Task '{event_id}' has been removed.")
-
         # Create an event entity for the removed job
         data_event = self.__getTaskFromSchedulerById(event_id, event_code)
 
         # If a listener is registered for this job ID, invoke the listener with the event details
         self.__taskCallableListener(data_event, ListeningEvent.JOB_ON_REMOVED)
 
+    def __triggerIsPast(
+        self,
+        signature: str,
+        entity: EventEntity
+    ) -> bool:
+        """
+        Determine if the trigger for a scheduled event is set to a date in the past.
+
+        This method checks whether the trigger associated with the given event entity is a
+        `DateTrigger` and, if so, compares its `run_date` to the current time in the scheduler's
+        configured timezone. If the trigger's run date is in the past, a warning is logged and
+        the method returns True, indicating that the event should be skipped.
+
+        Parameters
+        ----------
+        signature : str
+            The unique signature identifying the scheduled event.
+        entity : EventEntity
+            The event entity containing the trigger and scheduling information.
+
+        Returns
+        -------
+        bool
+            True if the event's trigger is a `DateTrigger` with a run date in the past; False otherwise.
+
+        Notes
+        -----
+        This method is used to prevent scheduling events that would immediately be considered expired.
+        """
+
+        # Check if the event's trigger is a DateTrigger and its run_date is in the past
+        if isinstance(entity.trigger, DateTrigger):
+            run_date = getattr(entity.trigger, 'run_date', None)
+            now = self.__getNow()
+
+            # If the run_date is set and is before the current time, log a warning and return True
+            if run_date is not None and run_date < now:
+                self.__logger.warning(
+                    f"Scheduled event '{signature}' has a run_date in the past ({run_date}); skipping."
+                )
+                return True
+
+        # Return False if the trigger is not a past DateTrigger
+        return False
+
+    def __eventToEntity(
+        self,
+        event
+    ) -> EventEntity:
+        """
+        Convert a scheduled event object to its corresponding EventEntity representation.
+
+        This method takes a scheduled event and transforms it into an `EventEntity` instance,
+        which encapsulates all relevant attributes required for internal tracking and management
+        within the scheduler. The conversion relies on the event implementing a `toEntity` method.
+
+        Parameters
+        ----------
+        event : Any
+            The scheduled event object to be converted. Must implement a `toEntity` method.
+
+        Returns
+        -------
+        EventEntity
+            An instance of `EventEntity` containing the extracted attributes from the event.
+
+        Raises
+        ------
+        CLIOrionisValueError
+            If the provided event does not implement a `toEntity` method.
+
+        Notes
+        -----
+        This method is used internally to standardize event objects for consistent handling
+        within the scheduler's job management system.
+        """
+
+        # Ensure the event has a toEntity method for conversion
+        if not hasattr(event, 'toEntity'):
+            raise CLIOrionisValueError("The event must have a 'toEntity' method for conversion.")
+
+        # Convert the event to its entity representation (EventEntity)
+        to_entity = getattr(event, 'toEntity')
+        return to_entity()
+
     def __loadEvents(
         self
     ) -> None:
         """
-        Load all scheduled events from the AsyncIOScheduler into the internal jobs list.
+        Synchronize and register all scheduled events with the AsyncIOScheduler.
 
-        This method synchronizes the internal jobs list (`self.__jobs`) with the events currently
-        registered in the AsyncIOScheduler. For each event in the internal events dictionary,
-        it converts the event to its entity representation, adds it to the jobs list, and schedules
-        it in the AsyncIOScheduler with the appropriate configuration. If a listener is associated
-        with the event, it is also registered. This ensures that all scheduled jobs are properly
-        tracked and managed by both the internal state and the scheduler.
+        This method updates the internal jobs list (`self.__jobs`) by converting each event in the internal
+        events dictionary to its corresponding entity representation. It then schedules these jobs in the
+        appropriate scheduler (control or main) based on their signature. Events with triggers set in the
+        past are skipped to prevent immediate expiration. Associated listeners are registered for each job
+        as needed. This ensures that all scheduled jobs are properly tracked and managed by both the internal
+        state and the scheduler.
 
         Parameters
         ----------
@@ -1149,65 +1237,51 @@ class Schedule(ISchedule):
         Returns
         -------
         None
-            This method does not return any value. It updates the internal jobs list and
-            registers jobs with the AsyncIOScheduler.
+            This method does not return any value. It updates the internal jobs list and registers jobs
+            with the AsyncIOScheduler.
 
         Raises
         ------
         CLIOrionisRuntimeError
-            If an error occurs while loading or scheduling an event, a runtime error is raised
-            with a descriptive message.
+            Raised if an error occurs while loading or scheduling an event.
 
         Notes
         -----
-        - Events are only loaded if the internal jobs list is empty.
-        - Each event must implement a `toEntity` method to be converted to an entity.
-        - Jobs are added to the scheduler with their respective configuration, and listeners
-          are registered if present.
+        - Events are loaded only if the internal jobs list is empty to avoid duplicate scheduling.
+        - Each event must implement a `toEntity` method for conversion.
+        - Jobs are added to the scheduler with their respective configuration, and listeners are registered if present.
         """
 
         # Only load events if the jobs list is empty to avoid duplicate scheduling
         if not self.__jobs:
 
+            # Lists to separate control jobs and custom jobs
+            control_jobs = []
+            custom_jobs = []
+
             # Iterate through all scheduled events in the internal events dictionary
             for signature, event in self.__events.items():
 
                 try:
 
-                    # Ensure the event has a toEntity method for conversion
-                    if not hasattr(event, 'toEntity'):
-                        continue
-
                     # Convert the event to its entity representation (EventEntity)
-                    to_entity = getattr(event, 'toEntity')
-                    entity: EventEntity = to_entity()
+                    entity = self.__eventToEntity(event)
+
+                    # Skip loading events with a DateTrigger set in the past
+                    if self.__triggerIsPast(signature, entity):
+                        continue
 
                     # Add the job entity to the internal jobs list
                     self.__jobs.append(entity)
 
-                    # Helper function to create a job function that calls the reactor
-                    def create_job_func(cmd, args_list):
-                        return lambda: self.__reactor.call(cmd, args_list)
-
-                    # Add the job to the AsyncIOScheduler with the specified configuration
-                    self.__scheduler.add_job(
-                        func=create_job_func(signature, list(entity.args)),
-                        trigger=entity.trigger,
-                        id=signature,
-                        name=signature,
-                        replace_existing=True,
-                        max_instances=entity.max_instances,
-                        misfire_grace_time=entity.misfire_grace_time
-                    )
-
-                    # If the event entity has an associated listener, register it
-                    if entity.listener:
-                        self.setListener(signature, entity.listener)
-
-                    # Log the successful loading of the scheduled event for debugging
-                    self.__logger.debug(f"Scheduled event '{signature}' loaded successfully.")
+                    # Determine which scheduler to use based on the job signature
+                    if signature in self.__control_operations:
+                        control_jobs.append((signature, entity))
+                    else:
+                        custom_jobs.append((signature, entity))
 
                 except Exception as e:
+
                     # Construct an error message for failed event loading
                     error_msg = f"Failed to load scheduled event '{signature}': {str(e)}"
 
@@ -1217,6 +1291,72 @@ class Schedule(ISchedule):
                     # Raise a runtime error to signal failure in loading the scheduled event
                     raise CLIOrionisRuntimeError(error_msg)
 
+            # Register control jobs with the control scheduler
+            self.__loadJobs(self.__control_scheduler, control_jobs)
+
+            # Register custom jobs with the main scheduler
+            self.__loadJobs(self.__scheduler, custom_jobs)
+
+            # Log the successful loading of the scheduled events for debugging
+            self.__logger.debug(f"Scheduled events loaded successfully: {len(self.__jobs)} jobs.")
+
+    def __loadJobs(
+        self,
+        scheduler: BaseScheduler,
+        events: List[Tuple[str, EventEntity]]
+    ) -> None:
+        """
+        Load and register jobs into the specified scheduler.
+
+        This method iterates over a list of event tuples, each containing a job signature and its corresponding
+        EventEntity. For each event, it creates a job function that invokes the reactor with the provided command
+        and arguments, then adds the job to the given scheduler with the appropriate configuration. If the event
+        entity has an associated listener, the listener is registered for the job.
+
+        Parameters
+        ----------
+        scheduler : BaseScheduler
+            The scheduler instance (either control or main) where jobs will be registered.
+        events : List[Tuple[str, EventEntity]]
+            A list of tuples, each containing a job signature and its corresponding EventEntity.
+
+        Returns
+        -------
+        None
+            This method does not return any value. It registers jobs and listeners with the scheduler.
+
+        Notes
+        -----
+        - The job function is created as a lambda that calls the reactor with the command and arguments.
+        - Jobs are added with configuration options such as trigger, ID, name, max instances, misfire grace time, and coalesce.
+        - If an event entity has a listener, it is registered using the setListener method.
+        """
+
+        # Helper function to create a job function that calls the reactor with the given command and arguments
+        def create_job_func(cmd, args_list):
+
+            # Returns a lambda that executes the reactor call for the specified command and arguments
+            return lambda: self.__reactor.call(cmd, args_list)
+
+        # Iterate over each event tuple and add the job to the scheduler
+        for signature, entity in events:
+
+            # Add the job to the scheduler with the specified configuration
+            scheduler.add_job(
+                func=create_job_func(signature, list(entity.args)),
+                trigger=entity.trigger,
+                id=signature,
+                name=f"{signature}({', '.join(map(str, entity.args))})",
+                replace_existing=True,
+                max_instances=entity.max_instances,
+                misfire_grace_time=entity.misfire_grace_time,
+                coalesce=entity.coalesce
+            )
+
+            # If the event entity has an associated listener, register it
+            if entity.listener:
+                self.setListener(signature, entity.listener)
+
     def __raiseException(
         self,
         exception: BaseException
@@ -1319,7 +1459,6 @@ class Schedule(ISchedule):
 
         # Register the listener for the specified event in the internal listeners dictionary
         self.__listeners[event] = listener
-        print(self.__listeners)
 
     def pause(
         self
@@ -1350,9 +1489,6 @@ class Schedule(ISchedule):
         # Only pause jobs if the scheduler is currently running
         if self.isRunning():
 
-            # Clear the set of previously paused jobs to avoid stale entries
-            self.__pausedByPauseEverything.clear()
-
             # Retrieve all jobs currently managed by the scheduler
             all_jobs = self.__scheduler.get_jobs()
 
@@ -1360,22 +1496,14 @@ class Schedule(ISchedule):
             for job in all_jobs:
 
                 try:
+
                     # Get the job ID safely
                     job_id = self.__getAttribute(job, 'id', None)
 
                     # Skip jobs without a valid user-defined ID (ignore system/operation jobs)
-                    if not job_id or not isinstance(job_id, str) or job_id.strip() == "" or job_id in self.__operations:
+                    if not job_id or not isinstance(job_id, str) or job_id.strip() == "":
                         continue
 
-                    # Pause the job in the scheduler
-                    self.__scheduler.pause_job(job_id)
-
-                    # Track the paused job's ID
-                    self.__pausedByPauseEverything.add(job_id)
-
-                    # Get the current time in the configured timezone for logging
-                    now = self.__getCurrentTime()
-
                     # Retrieve event data for the paused job
                     event_data = self.__getTaskFromSchedulerById(job_id)
 
@@ -1385,9 +1513,6 @@ class Schedule(ISchedule):
                         ListeningEvent.JOB_ON_PAUSED
                     )
 
-                    # Log the pause action for this job
-                    self.__logger.info(f"Task '{job_id}' paused successfully at {now}.")
-
                 except Exception as e:
 
                     # Handle any errors that occur while pausing a job
@@ -1399,8 +1524,17 @@ class Schedule(ISchedule):
                 time=self.__getNow()
             ), ListeningEvent.SCHEDULER_PAUSED)
 
+            # Get the current time in the configured timezone for logging
+            now = self.__getCurrentTime()
+
+            # Clear the set of previously paused jobs to avoid stale entries
+            self.__scheduler.pause()
+
+            # Store the timestamp when the scheduler was paused
+            self.__paused_at = self.__getNow()
+
             # Log that all tasks have been paused
-            self.__logger.info("All tasks have been paused.")
+            self.__logger.info(f"Orionis Scheduler paused all tasks successfully at: {now}.")
 
     def resume(
         self
@@ -1429,55 +1563,44 @@ class Schedule(ISchedule):
         """
 
         # Only resume jobs if the scheduler is currently running
-        if self.isRunning():
+        if self.isPaused():
 
-            # Resume only jobs that were paused by the pause method
-            if self.__pausedByPauseEverything:
+            # Execute the global callable listener after all jobs are resumed
+            self.__globalCallableListener(SchedulerResumed(
+                code=EVENT_SCHEDULER_RESUMED,
+                time=self.__getNow()
+            ), ListeningEvent.SCHEDULER_RESUMED)
 
-                # Iterate through the set of paused job IDs and resume each one
-                for job_id in self.__pausedByPauseEverything:
+            # Get the current time in the configured timezone for logging
+            now = self.__getCurrentTime()
 
-                    try:
+            # Cuando resumes:
+            resumed_at = self.__getNow()
 
-                        # Resume the job in the scheduler
-                        self.__scheduler.resume_job(job_id)
+            # Resume main scheduler
+            self.__scheduler.resume()
 
-                        # Retrieve event data for the resumed job
-                        event_data = self.__getTaskFromSchedulerById(job_id)
+            # Iterate through all jobs to check for missed executions
+            for job in self.__scheduler.get_jobs():
 
-                        # Invoke the listener for the resumed job event
-                        self.__taskCallableListener(
-                            event_data,
-                            ListeningEvent.JOB_ON_RESUMED
-                        )
+                # If the job was supposed to run while paused, trigger the missed event
+                if job.next_run_time and self.__paused_at <= job.next_run_time < resumed_at:
 
-                        # Log an informational message indicating that the job has been resumed
-                        self.__logger.info(f"Task '{job_id}' has been resumed.")
+                    # Retrieve event data for the missed job
+                    event_data = self.__getTaskFromSchedulerById(job.id)
 
-                    except Exception as e:
+                    # Invoke the listener for the missed job event
+                    self.__taskCallableListener(
+                        event_data,
+                        ListeningEvent.JOB_ON_MISSED
+                    )
 
-                        # Handle any errors that occur while resuming a job
-                        self.__raiseException(e)
+            # Log an informational message indicating that the scheduler has been resumed
+            self.__logger.info(f"Orionis Scheduler resumed all tasks successfully at: {now}.")
 
-                # Clear the set after resuming all jobs to avoid stale entries
-                self.__pausedByPauseEverything.clear()
-
-                # Execute the global callable listener after all jobs are resumed
-                self.__globalCallableListener(SchedulerResumed(
-                    code=EVENT_SCHEDULER_RESUMED,
-                    time=self.__getNow()
-                ), ListeningEvent.SCHEDULER_RESUMED)
-
-                # Get the current time in the configured timezone for logging
-                now = self.__getCurrentTime()
-
-                # Log an informational message indicating that the scheduler has been resumed
-                self.__logger.info(f"Orionis Scheduler resumed successfully at {now}.")
-
-                # Log that all previously paused jobs have been resumed
-                self.__logger.info("All previously task have been resumed.")
-
-    async def start(self) -> None:
+    async def start(
+        self
+    ) -> None:
         """
         Start the AsyncIO scheduler instance and keep it running.
 
@@ -1514,6 +1637,7 @@ class Schedule(ISchedule):
             # Start the scheduler if it is not already running
             if not self.isRunning():
                 self.__scheduler.start()
+                self.__control_scheduler.start()
 
             # Log that the scheduler is now active and waiting for events
             self.__logger.info("Orionis Scheduler is now active and waiting for events...")
@@ -1553,7 +1677,10 @@ class Schedule(ISchedule):
             # Raise a runtime error for any other issues during startup
             raise CLIOrionisRuntimeError(f"Failed to start the scheduler: {str(e)}") from e
 
-    async def shutdown(self, wait: bool = True) -> None:
+    async def shutdown(
+        self,
+        wait: bool = True
+    ) -> None:
         """
         Shut down the AsyncIO scheduler instance asynchronously.
 
@@ -1587,15 +1714,13 @@ class Schedule(ISchedule):
 
         # If the scheduler is not running, there's nothing to shut down
         if not self.isRunning():
-            self.__logger.info("The scheduler is already stopped. No shutdown action is required.")
             return
 
         try:
-            # Log the shutdown process
-            self.__logger.info(f"Starting Orionis Scheduler shutdown process (wait={wait})...")
 
             # Shut down the AsyncIOScheduler
             self.__scheduler.shutdown(wait=wait)
+            self.__control_scheduler.shutdown(wait=wait)
 
             # Signal the stop event to break the wait in start()
             if self._stop_event and not self._stop_event.is_set():
@@ -1605,10 +1730,14 @@ class Schedule(ISchedule):
             if wait:
                 await asyncio.sleep(0.1)
 
+            # Get the current time in the configured timezone for logging
+            now = self.__getCurrentTime()
+
             # Log the successful shutdown
-            self.__logger.info("Orionis Scheduler has been shut down successfully.")
+            self.__logger.info(f"Orionis Scheduler has been shut down successfully at: {now}.")
 
         except Exception as e:
+
             # Handle exceptions that may occur during shutdown
             self.__raiseException(
                 CLIOrionisRuntimeError(
@@ -1616,7 +1745,10 @@ class Schedule(ISchedule):
                 )
             )
 
-    def pauseTask(self, signature: str) -> bool:
+    def pauseCommand(
+        self,
+        signature: str
+    ) -> bool:
         """
         Pause a scheduled job in the AsyncIO scheduler.
 
@@ -1652,9 +1784,19 @@ class Schedule(ISchedule):
             self.__raiseException(CLIOrionisValueError(self.SIGNATURE_REQUIRED_ERROR))
 
         try:
+
             # Attempt to pause the job with the given signature
             self.__scheduler.pause_job(signature)
 
+            # Retrieve event data for the paused job
+            event_data = self.__getTaskFromSchedulerById(signature)
+
+            # Invoke the listener for the paused job event
+            self.__taskCallableListener(
+                event_data,
+                ListeningEvent.JOB_ON_PAUSED
+            )
+
             # Log the successful pausing of the job
             self.__logger.info(f"Pause '{signature}' has been paused.")
 
@@ -1666,7 +1808,10 @@ class Schedule(ISchedule):
             # Return False if the job could not be paused (e.g., it does not exist or another error occurred)
             return False
 
-    def resumeTask(self, signature: str) -> bool:
+    def resumeCommand(
+        self,
+        signature: str
+    ) -> bool:
         """
         Resume a paused job in the AsyncIO scheduler.
 
@@ -1706,6 +1851,15 @@ class Schedule(ISchedule):
             # Attempt to resume the job with the given signature
             self.__scheduler.resume_job(signature)
 
+            # Retrieve event data for the resumed job
+            event_data = self.__getTaskFromSchedulerById(signature)
+
+            # Invoke the listener for the resumed job event
+            self.__taskCallableListener(
+                event_data,
+                ListeningEvent.JOB_ON_RESUMED
+            )
+
             # Log the successful resumption of the job
             self.__logger.info(f"Task '{signature}' has been resumed.")
 
@@ -1717,7 +1871,10 @@ class Schedule(ISchedule):
             # Return False if the job could not be resumed (e.g., it does not exist or another error occurred)
             return False
 
-    def removeTask(self, signature: str) -> bool:
+    def removeCommand(
+        self,
+        signature: str
+    ) -> bool:
         """
         Remove a scheduled job from the AsyncIO scheduler by its signature.
 
@@ -1775,7 +1932,9 @@ class Schedule(ISchedule):
             # Return False if the job could not be removed (e.g., it does not exist or another error occurred)
             return False
 
-    def events(self) -> List[Dict]:
+    def events(
+        self
+    ) -> List[Dict]:
         """
         Retrieve a list of all scheduled jobs managed by the scheduler.
 
@@ -1818,6 +1977,9 @@ class Schedule(ISchedule):
             start_date: datetime = self.__getAttribute(job, 'start_date', None)
             end_date: datetime = self.__getAttribute(job, 'end_date', None)
             details: str = self.__getAttribute(job, 'details', 'Not Available')
+            coalesce: bool = self.__getAttribute(job, 'coalesce', False)
+            max_instances: int = self.__getAttribute(job, 'max_instances', 1)
+            misfire_grace_time: int = self.__getAttribute(job, 'misfire_grace_time', None)
 
             # Format the start and end dates as strings, or mark as 'Not Applicable' if not set
             formatted_start = start_date.strftime('%Y-%m-%d %H:%M:%S') if start_date else self.NOT_APPLICABLE
@@ -1831,7 +1993,10 @@ class Schedule(ISchedule):
                 'random_delay': random_delay,
                 'start_date': formatted_start,
                 'end_date': formatted_end,
-                'details': details
+                'details': details,
+                'coalesce': coalesce,
+                'max_instances': max_instances,
+                'misfire_grace_time': misfire_grace_time
             })
 
         # Return the list of scheduled job details
@@ -1909,7 +2074,9 @@ class Schedule(ISchedule):
         # Return None if no job with the given signature is found
         return None
 
-    def isRunning(self) -> bool:
+    def isRunning(
+        self
+    ) -> bool:
         """
         Check if the scheduler is currently running.
 
@@ -1924,9 +2091,11 @@ class Schedule(ISchedule):
         """
 
         # Return True if the scheduler is running, otherwise False
-        return self.__scheduler.running
+        return self.__scheduler.running and self.__scheduler.state == STATE_RUNNING
 
-    def isPaused(self) -> bool:
+    def isPaused(
+        self
+    ) -> bool:
         """
         Check if the scheduler is currently paused.
 
@@ -1942,9 +2111,11 @@ class Schedule(ISchedule):
         """
 
         # The scheduler is considered paused if there are any jobs in the paused set
-        return len(self.__pausedByPauseEverything) > 0
+        return self.__scheduler.running and self.__scheduler.state == STATE_PAUSED
 
-    def forceStop(self) -> None:
+    def forceStop(
+        self
+    ) -> None:
         """
         Forcefully stop the scheduler immediately, bypassing graceful shutdown.
 
@@ -1969,12 +2140,15 @@ class Schedule(ISchedule):
         # If the scheduler is currently running, shut it down immediately without waiting for jobs to finish
         if self.__scheduler.running:
             self.__scheduler.shutdown(wait=False)
+            self.__control_scheduler.shutdown(wait=False)
 
         # If the stop event exists and has not already been set, signal it to interrupt the main loop
         if self._stop_event and not self._stop_event.is_set():
             self._stop_event.set()
 
-    def stop(self) -> None:
+    def stop(
+        self
+    ) -> None:
         """
         Signal the scheduler to stop synchronously by setting the internal stop event.
 
