@@ -97,7 +97,7 @@ class SQLite(BaseEntity):
         },
     )
 
-    def __post_init__(self):
+    def __post_init__(self): # NOSONAR
         super().__post_init__()
         """
         Post-initialization validation for SQLite database configuration fields.
